# -*- coding: utf-8 -*-
# Copyright (C) 2014-2024  EDF
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See https://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#
# Author : Konstantin Leontev (OpenCascade S.A.S)

import logging

from qtsalome import QPlainTextEdit, pyqtSignal, QObject, pyqtSlot

from salome.kernel.logger import Logger
logger = Logger("salome.geom.geomrepairadv", level = logging.DEBUG)


class QTextEditLogger(QObject, logging.Handler):
    """
    Provides a QPlainTextEdit text_widget that automaticly filled
    by logs text from the logger handler.
    """

    append_text = pyqtSignal(str)

    def __init__(self, parent):
        super().__init__(parent)
        super(logging.Handler).__init__()


        self.text_widget = QPlainTextEdit(parent)
        self.text_widget.setReadOnly(True)
        self.append_text.connect(self.write_log)

        formatter = logging.Formatter(
            '%(levelname)s : %(asctime)s : [%(filename)s:%(funcName)s:%(lineno)s] : %(message)s')
        self.setFormatter(formatter)

    def emit(self, record):
        msg = self.format(record)
        self.append_text.emit(msg)


    @pyqtSlot(str)
    def write_log(self, log_text):
        """
        Appends a given log to the text widget.
        """

        self.text_widget.appendPlainText(log_text)
        self.text_widget.centerCursor()  # scroll to the bottom
